@@ -5,9 +5,8 @@ from typing import Any, Optional, Type, Union
 
 import graphene
 import sqlalchemy as sa
-from graphene import Field, Scalar
+from graphene import Field, ResolveInfo, Scalar
 from graphene.types.objecttype import ObjectTypeMeta
-from graphql import GraphQLResolveInfo
 from sqlalchemy import Table
 from sqlalchemy.exc import ArgumentError
 from sqlalchemy.orm import DeclarativeMeta, class_mapper, mapperlib, object_mapper
@@ -34,14 +33,16 @@ class GlobalFilters:
     ID__IN = "id__in"
 
 
-def get_query(model: Type[DeclarativeMeta], info: GraphQLResolveInfo, cls_name=None):
-    try:
-        if info:
+def get_query(model: Type[DeclarativeMeta], info: ResolveInfo, cls_name=None):
+    fields = None
+
+    if info:
+        try:
             fields = get_fields(model, info, cls_name)
-        else:
-            fields = model.__table__.columns
-    except Exception as e:
-        logging.error(e)
+        except Exception as e:
+            logging.error(e)
+
+    if not fields:
         fields = model.__table__.columns
 
     return sa.select(fields)
